%define oname Thunar
%define iconname thunar.png

%define major 2
%define apiversion 1
%define libname %mklibname %{name} %{apiversion} %{major}
%define develname %mklibname %{name} -d

Summary:	New modern file manager for the Xfce Desktop Environment
Name:		thunar
Version:	1.0.1
Release:	%mkrel 7
License:	GPLv2+
Group:		Graphical desktop/Xfce
URL:		http://thunar.xfce.org
Source0:	http://www.xfce.org/archive/xfce-%{version}/src/%{oname}-%{version}.tar.bz2
#(tpg) http://bugzilla.xfce.org/show_bug.cgi?id=3614
# (tpg) here's the never, and probably better version of the patch https://qa.mandriva.com/show_bug.cgi?id=40230
Patch3:		%{oname}-1.0.1-icons-extension-strip.patch
Patch4:		%{oname}-0.9.0-dont-die-on-dbus-disconnect.patch
# (Anssi 06/2008) fix underlinking:
Patch5:		%{oname}-0.9.0-fix-underlinking.patch
# (tpg) prevent crashing of Thunar when you are drag'n'drop some unhandled formats e.g text
Patch6:		Thunar-1.0.1-dont-crash-on-dnd-unhandled-formats.patch
BuildRequires:	libgdk_pixbuf2.0-devel
BuildRequires:	exo-devel
BuildRequires:	gamin-devel
BuildRequires:	hal-devel
BuildRequires:	perl(XML::Parser)
BuildRequires:	dbus-glib-devel
BuildRequires:	desktop-file-utils
BuildRequires:	xfce4-panel-devel >= 4.6.0
BuildRequires:	libpng-devel
BuildRequires:	libjpeg-devel
BuildRequires:	libpcre-devel
BuildRequires:	libexif-devel
BuildRequires:	libGConf2-devel
BuildRequires:	libusb-devel
BuildRequires:	xfconf-devel
# for patch 5
BuildRequires:	intltool
BuildRequires:	desktop-file-utils
Requires:	shared-mime-info >= 0.15
Requires:	exo
Requires:	thunar-volman
Requires:	%{libname} = %{version}-%{release}
Requires(post):	desktop-file-utils >= 0.10
Requires(postun): desktop-file-utils >= 0.10
Obsoletes:	xffm
BuildRoot:	%{_tmppath}/%{name}-%{version}-buildroot

%description
Thunar has been designed from the ground up to be fast and easy-to-use.
Its user interface is clean and intuitive, and does not include any confusing
or useless options. Thunar is fast and responsive with a good start up time
and directory load time. Thunar is accessible using Assistive Technologies and
is fully standards  compliant.

Beside the basic file management features, Thunar includes additional features
that set it ahead of other file managers available for the Unix/Linux desktop
today. For example, Thunar includes a so called Bulk Renamer that allows users
to easily rename multiple files at once using criterions that can be specified
using the available renamer plugins. Probably the most interesting renamer here
is the Audio Tags renamer, which generates new file names based on the tags
present in audio files.

Using the Thunar Extensions Framework it is easy to extend the basic
functionality provided by Thunar to integrate even complex tasks into the file
manager, although the extension framework is still very limited in the 1.0
series, and the 2.0 series will include a way more powerful plugin interface
that allows to adjust virtually every aspect of the file manager. But since
writing extensions for the file manager is still a difficult and time consuming
job, the User Customizable Actions plugin provides users with an easy way to
extend the file and folder context menus with their own custom actions.

%package -n %{libname}
Summary:	Libraries for the thunar filemanager
Group:		Graphical desktop/Xfce

%description -n %{libname}
Libraries for the thunar filemanager.

%package -n %{develname}
Summary:	Development files for the thunar filemanager
Group:		Development/Other
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Obsoletes:	%mklibname %{name} 1 2 -d

%description -n %{develname}
Development files for the thunar filemanager.

%prep
%setup -qn %{oname}-%{version}
%patch3 -p1 -b .icon
%patch4 -p1 -b .dbus
%patch5 -p1
%patch6 -p1

%build

# re-generate it
pushd thunar
exo-csource --name=thunar_window_ui thunar-window-ui.xml > thunar-window-ui.h
popd

# for patch 5:
NOCONFIGURE=1 xdt-autogen

%configure2_5x \
%if %mdkversion < 200900
    --sysconfdir=%{_sysconfdir}/X11 \
%endif
    --with-volume-manager=hal \
    --enable-dbus \
    --enable-gnome-thumbnailers \
    --enable-startup-notification \
    --enable-exif \
    --enable-pcre \
    --enable-gtk-doc \
    --enable-apr-plugin \
    --enable-tpa-plugin \
    --enable-uca-plugin \
    --enable-wallpaper-plugin

%make

%install
rm -rf %{buildroot}
%makeinstall_std

desktop-file-install \
    --remove-key="Encoding" \
    --add-category="FileManager;FileTools" \
    --remove-category="Application" \
    --add-only-show-in="XFCE" \
    --remove-mime-type="x-directory/normal;x-directory/gnome-default-handler" \
    --dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/Thunar*

desktop-file-install \
    --add-category="FileManager" \
    --add-only-show-in="XFCE" \
    --dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/thunar-settings.desktop

# Remove unneeded files
rm -f %{buildroot}%{_libdir}/thunarx-1/thunar-uca.la
rm -f %{buildroot}%{_datadir}/doc/Thunar/README.thunarrc
rm -f %{buildroot}%{_datadir}/doc/Thunar/README.volumes

%find_lang %{oname}

%clean
rm -rf %{buildroot}

%if %mdkversion < 200900
%post
%{update_menus}
%{update_desktop_database}
%{update_mime_database}
%update_icon_cache hicolor
%endif

%if %mdkversion < 200900
%postun
%{clean_menus}
%{clean_desktop_database}
%{clean_mime_database}
%clean_icon_cache hicolor
%endif

%if %mdkversion < 200900
%post -n %{libname} -p /sbin/ldconfig
%endif

%if %mdkversion < 200900
%postun -n %{libname} -p /sbin/ldconfig
%endif

%files -f %{oname}.lang
%defattr(-,root,root)
%doc AUTHORS FAQ HACKING README THANKS TODO
%doc docs/README.*
%if %mdkversion < 200900
%dir %{_sysconfdir}/X11/xdg/Thunar
%exclude %{_sysconfdir}/X11/xdg/Thunar/uca.xml
%else
%dir %{_sysconfdir}/xdg/Thunar
%exclude %{_sysconfdir}/xdg/Thunar/uca.xml
%endif
%dir %{_datadir}/Thunar
%{_bindir}/*
%{_datadir}/applications/*
%{_iconsdir}/hicolor/*
%{_datadir}/pixmaps/*
%{_datadir}/dbus-1/services/*
%{_datadir}/doc/Thunar
%{_datadir}/Thunar/sendto/thunar-sendto-email.desktop
%{_libdir}/thunarx-1/thunar-uca.so
%{_libdir}/ThunarHelp
%{_libdir}/thunar-vfs-mime-cleaner-1
%{_libdir}/ThunarBulkRename
%{_libdir}/thunarx-1
%{_libdir}/thunar-sendto-email
%{_libdir}/thunar-vfs-font-thumbnailer-1
%{_libdir}/thunar-vfs-pixbuf-thumbnailer-1
%{_libdir}/thunar-vfs-update-thumbnailers-cache-1
%{_mandir}/man1/*
%{_datadir}/thumbnailers/thunar-vfs-font-thumbnailer-1.desktop
%{_libdir}/xfce4/panel-plugins/thunar-tpa
%{_datadir}/xfce4/panel-plugins/thunar-tpa.desktop
%{_datadir}/gtk-doc/html/thunar-vfs/*
%{_datadir}/gtk-doc/html/thunarx/*

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/*%{apiversion}.so.%{major}*

%files -n %{develname}
%defattr(-,root,root)
%dir %{_includedir}/thunar-vfs-1
%{_includedir}/thunar-vfs-1/*
%dir %{_includedir}/thunarx-1
%{_includedir}/thunarx-1/*
%{_libdir}/lib*.so
%{_libdir}/lib*.*a
%{_libdir}/pkgconfig/*.pc


%changelog
* Thu Jun 03 2010 Ahmad Samir <ahmadsamir@mandriva.org> 1.0.1-7mdv2010.1
+ Revision: 547012
- rebuild for exo

* Tue Mar 16 2010 Ahmad Samir <ahmadsamir@mandriva.org> 1.0.1-6mdv2010.1
+ Revision: 522198
- fix .desktop files

* Wed Jan 13 2010 Götz Waschk <waschk@mandriva.org> 1.0.1-5mdv2010.1
+ Revision: 490562
- rebuild for new libjpeg

* Sat Jan 02 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.1-4mdv2010.1
+ Revision: 484943
- fix patch
- add buildrequires on xfconf-devel
- Patch6: prevent crashing of Thunar when you are drag'n'drop some unhandled formats e.g text

* Sun Aug 16 2009 Götz Waschk <waschk@mandriva.org> 1.0.1-3mdv2010.0
+ Revision: 416911
- rebuild for new libjpeg

* Sun Jun 14 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.1-2mdv2010.0
+ Revision: 385898
- Patch3: strip jpg icon extension too
- re-generate thunar-window-ui.h file before build

* Wed Apr 22 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.1-1mdv2010.0
+ Revision: 368750
- update to new version 1.0.1

* Mon Apr 06 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.0-3mdv2009.1
+ Revision: 364439
- Patch6: properly apply umask for new files and directories

* Thu Mar 05 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.0-2mdv2009.1
+ Revision: 349178
- rebuild whole xfce

* Fri Feb 27 2009 Jérôme Soyer <saispo@mandriva.org> 1.0.0-1mdv2009.1
+ Revision: 345736
- New upstream release

* Mon Jan 26 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.99.1-1mdv2009.1
+ Revision: 333835
- update to new version 0.9.99.1

* Wed Jan 14 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.93-1mdv2009.1
+ Revision: 329512
- update to new version 0.9.93

* Sat Nov 15 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.92-2mdv2009.1
+ Revision: 303565
- drop patch 5 as it was merged by upstream
- add full path for the Source0
- update to new version 0.9.92 (Xfce 4.6 Beta 2 Hopper)

* Thu Nov 13 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.91-2mdv2009.1
+ Revision: 302658
- rebuilt against new libxcb

* Fri Oct 17 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.91-1mdv2009.1
+ Revision: 294526
- Xfce4.6 beta1 is landing on cooker
- drop patches 0, 1, 2 and 3

* Sun Oct 12 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-18mdv2009.1
+ Revision: 292835
- Patch6: new version from xfce bugzilla

* Fri Oct 10 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-17mdv2009.1
+ Revision: 291557
- Patch6: new version from xfce bugzilla

* Mon Sep 22 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-16mdv2009.0
+ Revision: 286706
- Patch6: new version

* Fri Sep 19 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-15mdv2009.0
+ Revision: 285955
- Patch6: rediff
- Patch6: new version (from xfce upstream bug #4365)
- require libname

* Sun Sep 14 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-13mdv2009.0
+ Revision: 284698
- Patch6: new version (from xfce upstream bug #4365)

* Fri Sep 05 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-12mdv2009.0
+ Revision: 281250
- Patch6: new version of patch

* Tue Aug 19 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-11mdv2009.0
+ Revision: 273491
- Patch6: use XDG user environment variables

* Mon Jun 16 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-10mdv2009.0
+ Revision: 219511
- add buildrequires on intltool
- fix file list

  + Anssi Hannula <anssi@mandriva.org>
    - fix underlinking (fix-underlinking.patch)

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Thierry Vignaud <tv@mandriva.org>
    - fix spacing in summary

* Sun May 11 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-9mdv2009.0
+ Revision: 205641
- change sysconfdir from /etc/X11/xdg to /etc/xdg only for Mandriva releases newer than 2008.1

* Wed Apr 30 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-8mdv2009.0
+ Revision: 199464
- Patch4: don't die on dbus disconnect

* Thu Apr 24 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-7mdv2009.0
+ Revision: 197186
- Patch3: new version of stripping extension patch, fixes bug #40230 (tasty cookie goes to incubusss ;)

* Fri Mar 21 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-6mdv2008.1
+ Revision: 189406
- Patch3: fix entension stripping for icons (Xfce upstream bug #3614)

* Wed Mar 19 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-5mdv2008.1
+ Revision: 188986
- add missing buildrequires on libusb-devel
- rebuild

  + Thierry Vignaud <tv@mandriva.org>
    - fix description-line-too-long
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Dec 17 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-4mdv2008.1
+ Revision: 121150
- add patch 2 (show Eject for all removeable media. not only for disks)

* Thu Dec 13 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.0-3mdv2008.1
+ Revision: 119151
- provide better version on patch 0 (please see http://bugzilla.xfce.org/show_bug.cgi?id=2983)

  + Thierry Vignaud <tv@mandriva.org>
    - do not package big ChangeLog

* Tue Dec 04 2007 Jérôme Soyer <saispo@mandriva.org> 0.9.0-2mdv2008.1
+ Revision: 115264
- Add Upstream Patch and bump release

* Tue Dec 04 2007 Jérôme Soyer <saispo@mandriva.org> 0.9.0-1mdv2008.1
+ Revision: 115199
- New release 0.9.0

  + Thierry Vignaud <tv@mandriva.org>
    - fix summary-ended-with-dot

* Tue Nov 20 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.8.0-10mdv2008.1
+ Revision: 110603
- update summary
- update description
- remove buildrequires on libxml2-devel
- add missing buildrequires on libpcre,libexif,libpng,libjpeg and libGConf2
- new license policy
- revert last change
- fix desktop entry

* Fri Sep 21 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.8.0-8mdv2008.0
+ Revision: 91878
- exclude config files which are now in mandriva-xfce-config package

* Tue Sep 04 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.8.0-7mdv2008.0
+ Revision: 79434
- provide patch 0, which prevent zombie process
- set configure options

* Sat Aug 25 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.8.0-6mdv2008.0
+ Revision: 71243
- man pages are now lzma'd
- adjust provides
- own directory
- fix file list
- new devel library policy
- drop X-MandrivaLinux
- add missing scriplets

* Thu Jun 07 2007 Anssi Hannula <anssi@mandriva.org> 0.8.0-5mdv2008.0
+ Revision: 36206
- rebuild with correct optflags

  + Jérôme Soyer <saispo@mandriva.org>
    - Rebuild for Applet in Panel

* Thu May 31 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.8.0-3mdv2008.0
+ Revision: 32993
- revert libname
- correct %%{major}
- drop old menu style
- add macros to %%post and %%postun
- drop buildrequires on ImageMagick
- spec file clean


* Tue Apr 03 2007 Jérôme Soyer <saispo@mandriva.org> 0.8.0-2mdv2007.1
+ Revision: 150358
- Add thunar Requires

* Tue Jan 23 2007 Sébastien Savarin <plouf@mandriva.org> 0.8.0-1mdv2007.1
+ Revision: 112319
- New release 0.8.0

  + Jérôme Soyer <saispo@mandriva.org>
    - Add Obsoletes

* Fri Dec 15 2006 Jérôme Soyer <saispo@mandriva.org> 0.5.0rc2-2mdv2007.1
+ Revision: 97238
- Fix build
- Fix %%files
- fix buildrequires
- Fix release
- Add BuildRequires
- New release

* Sat Dec 02 2006 Pascal Terjan <pterjan@mandriva.org> 0.3.2-0.beta2.6mdv2007.1
+ Revision: 90083
- Rebuild for new DBUS

  + Nicolas Lécureuil <neoclust@mandriva.org>
    - Add BuildRequires
    - import thunar-0.3.2-0.beta2.4mdv2007.0

* Wed Aug 02 2006 Charles A Edwards <eslrahc@mandriva.org> 0.3.2-0.beta2.4mdv2007.0
- rebuild for new dbus

* Thu Jul 13 2006 Charles A Edwards <eslrahc@mandriva.org> 0.3.2-0.beta2.3mdv2007.0
- use icon marco properly

* Thu Jul 13 2006 Charles A Edwards <eslrahc@mandriva.org> 0.3.2-0.beta2.2mdv2007.0
- add showonly to .desktop
- use icon marco

* Tue Jul 11 2006 Charles A Edwards <eslrahc@mandriva.org> 0.3.2-0.beta2.1mdv2007.0
- 0.3.2beta2
- xdg
- update file list

* Wed Apr 26 2006 Jerome Soyer <saispo@mandriva.org> 0.3.0-0.beta1.1mdk
- Tue Apr 18 2006 trem <trem@mandriva.org> 0.3.0-0.beta1.1mdk
- 0.3.0beta1

* Sat Mar 11 2006 Marcel Pol <mpol@mandriva.org> 0.2.3-0.svn_r20246.1mdk
- svn r20246
- new soname
- requires exo
- buildrequires hal-devel
- update filelist

* Sun Feb 05 2006 Marcel Pol <mpol@mandriva.org> 0.2.1-0.svn_r19739.2mdk
- buildrequires perl-XML-Parser

* Sun Feb 05 2006 Marcel Pol <mpol@mandriva.org> 0.2.1-0.svn_r19739.1mdk
- 0.2.1 svn r19739
- initial Mandriva package

